@@ -47,12 +47,15 @@
 #include <simgear/timing/timestamp.hxx>
 
 #include <simgear/misc/sg_hash.hxx>
+#include <string>
 
 #include "HTTPRepository_private.hxx"
 
 namespace simgear
 {
 
+using namespace std::string_literals;
+
 namespace {
 
 std::string innerResultCodeAsString(HTTPRepository::ResultCode code) {
@@ -197,22 +200,23 @@ public:
     {
         SGPath fpath(absolutePath());
         fpath.append(".dirindex");
-        updatedFileContents(fpath, hash);
+        updatedFileContents(fpath, "SELF", hash);
 
         children.clear();
         parseDirIndex(children);
         std::sort(children.begin(), children.end());
 
         _repository->updatedChildSuccessfully(_relativePath);
+        _repository->lastUpdatedDir = _relativePath;
     }
 
-    void failedToUpdate(HTTPRepository::ResultCode status)
+    void failedToUpdate(HTTPRepository::ResultCode status, const std::string& details)
     {
         if (_relativePath.empty()) {
             // root dir failed
-            _repository->failedToGetRootIndex(status);
+            _repository->failedToGetRootIndex(status, details);
         } else {
-            _repository->failedToUpdateChild(_relativePath, status);
+            _repository->failedToUpdateChild(_relativePath, status, details);
         }
     }
 
@@ -280,7 +284,7 @@ public:
             child.path.set_cached(true);
 
             std::string hash = computeHashForPath(child.path);
-            updatedFileContents(child.path, hash);
+            updatedFileContents(child.path, child.name, hash);
         }
     }
 
@@ -323,7 +327,11 @@ public:
                               LocalFileMatcher(c));
 
         const bool isNew = (p == fsChildren.end());
-        const bool upToDate = hashForChild(c) == c.hash;
+        const bool isCurrent = hashForChild(c) == c.hash;
+
+        if (!isCurrent) {
+            SG_LOG(SG_TERRASYNC, SG_DEBUG, "Hash mismatch for " << c.name << ": have " << hashForChild(c) << ", but need:" << c.hash);
+        }
 
         if (!isNew) {
           orphans.erase(std::remove(orphans.begin(), orphans.end(), *p),
@@ -339,7 +347,7 @@ public:
           const auto pathOnDisk = isNew ? absolutePath() / c.name : *p;
           // never handle deletes here, do them at the end
           const auto action =
-              isNew ? SAct::Add : (upToDate ? SAct::UpToDate : SAct::Update);
+              isNew ? SAct::Add : (isCurrent ? SAct::UpToDate : SAct::Update);
           const HTTPRepository::SyncItem item = {relativePath(), c.type, c.name,
                                                  action, pathOnDisk};
 
@@ -352,16 +360,16 @@ public:
         if (isNew) {
           // File or directory does not exist on local disk, so needs to be updated.
           toBeUpdated.push_back(c);
-        } else if (!upToDate) {
-          // File/directory exists, but hash doesn't match.
-          toBeUpdated.push_back(c);
+        } else if (!isCurrent) {
+            // File/directory exists, but hash doesn't match.
+            toBeUpdated.push_back(c);
         } else {
-          // File/Directory exists and hash is valid.
-          if (c.type == HTTPRepository::DirectoryType) {
-            // If it's a directory,perform a recursive check.
-            HTTPDirectory *childDir = childDirectory(c.name);
-            _repository->scheduleUpdateOfChildren(childDir);
-          }
+            // File/Directory exists and hash is valid.
+            if (c.type == HTTPRepository::DirectoryType) {
+                // If it's a directory,perform a recursive check.
+                HTTPDirectory* childDir = childDirectory(c.name);
+                _repository->scheduleUpdateOfChildren(childDir);
+            }
         }
       } // of repository-defined (well, .dirIndex) children iteration
 
@@ -399,7 +407,9 @@ public:
       try {
           removeOrphans(orphans);
       } catch (sg_exception& e) {
-          _repository->failedToUpdateChild(_relativePath, HTTPRepository::ResultCode::REPO_ERROR_IO);
+          _repository->failedToUpdateChild(_relativePath,
+                                           HTTPRepository::ResultCode::REPO_ERROR_IO,
+                                           "IO failure while removing orphans:"s + e.getFormattedMessage());
       }
 
       scheduleUpdates(toBeUpdated);
@@ -493,16 +503,16 @@ public:
               file.close();
 
               if (!extractor.isAtEndOfArchive()) {
-                  SG_LOG(SG_TERRASYNC, SG_ALERT, "Corrupt tarball " << relativePath);
                   repo->failedToUpdateChild(relativePath,
-                                            HTTPRepository::REPO_ERROR_IO);
+                                            HTTPRepository::REPO_ERROR_IO,
+                                            "ArchiveExtractTask: got EOF msimatch");
                   return HTTPRepoPrivate::ProcessFailed;
               }
 
               if (extractor.hasError()) {
-                  SG_LOG(SG_TERRASYNC, SG_ALERT, "Error extracting " << relativePath);
                   repo->failedToUpdateChild(relativePath,
-                                            HTTPRepository::REPO_ERROR_IO);
+                                            HTTPRepository::REPO_ERROR_IO,
+                                            "ArchiveExtractTask: extractor error");
                   return HTTPRepoPrivate::ProcessFailed;
               }
 
@@ -544,14 +554,14 @@ public:
             SG_LOG(SG_TERRASYNC, SG_WARN, "updated file but not found in dir:" << _relativePath << " " << file);
         } else {
             if (it->hash != hash) {
-                SG_LOG(SG_TERRASYNC, SG_WARN, "Checksum error for " << absolutePath() << "/" << file << " " << it->hash << " " << hash);
                 // we don't erase the file on a hash mismatch, because if we're syncing during the
                 // middle of a server-side update, the downloaded file may actually become valid.
                 _repository->failedToUpdateChild(
                     _relativePath + "/" + file,
-                    HTTPRepository::REPO_ERROR_CHECKSUM);
+                    HTTPRepository::REPO_ERROR_CHECKSUM,
+                    "Checksum error after updating file: "s + it->hash + " vs "s + hash);
             } else {
-                updatedFileContents(it->path, hash);
+                updatedFileContents(it->path, file, hash);
                 _repository->updatedChildSuccessfully(_relativePath + "/" +
                                                       file);
 
@@ -559,72 +569,63 @@ public:
                 SGPath p = SGPath(absolutePath(), file);
 
                 if (it->type == HTTPRepository::TarballType) {
-                    // We require that any compressed files have the same filename as the file or directory
-                    // they expand to, so we can remove the old file/directory before extracting the new
-                    // data.
-                    SGPath removePath = SGPath(p.base());
-                    bool pathAvailable = true;
-                    if (removePath.exists()) {
-                        if (removePath.isDir()) {
-                            simgear::Dir pd(removePath);
-                            pathAvailable = pd.removeChildren();
-                        } else {
-                            pathAvailable = removePath.remove();
-                        }
-                    }
-
-                    if (pathAvailable) {
-                        // we use a Task helper to extract tarballs incrementally.
-                        // without this, archive extraction blocks here, which
-                        // prevents other repositories downloading / updating.
-                        // Unfortunately due Windows AV (Defender, etc) we cna block
-                        // here for many minutes.
-
-                        // use a lambda to own this shared_ptr; this means when the
-                        // lambda is destroyed, the ArchiveExtraTask will get
-                        // cleaned up.
-                        ArchiveExtractTaskPtr t =
-                            std::make_shared<ArchiveExtractTask>(p, _relativePath);
-                        auto cb = [t](HTTPRepoPrivate* repo) {
-                            return t->run(repo);
-                        };
-                        _repository->bytesToExtract += t->archiveSizeBytes();
-                        _repository->addTask(cb);
-                    } else {
-                        SG_LOG(SG_TERRASYNC, SG_ALERT, "Unable to remove old file/directory " << removePath);
-                    } // of pathAvailable
+                    didUpdateTarballFile(p);
                 }     // of handling archive files
             } // of hash matches
         } // of found in child list
     }
 
+    void didUpdateTarballFile(SGPath p)
+    {
+        // We require that any compressed files have the same filename as the file or directory
+        // they expand to, so we can remove the old file/directory before extracting the new
+        // data.
+        SGPath removePath = SGPath(p.base());
+        bool pathAvailable = true;
+        if (removePath.exists()) {
+            if (removePath.isDir()) {
+                simgear::Dir pd(removePath);
+                pathAvailable = pd.removeChildren();
+            } else {
+                pathAvailable = removePath.remove();
+            }
+        }
+
+        if (pathAvailable) {
+            // we use a Task helper to extract tarballs incrementally.
+            // without this, archive extraction blocks here, which
+            // prevents other repositories downloading / updating.
+            // Unfortunately due Windows AV (Defender, etc) we cna block
+            // here for many minutes.
+
+            // use a lambda to own this shared_ptr; this means when the
+            // lambda is destroyed, the ArchiveExtraTask will get
+            // cleaned up.
+            ArchiveExtractTaskPtr t =
+                std::make_shared<ArchiveExtractTask>(p, _relativePath);
+            auto cb = [t](HTTPRepoPrivate* repo) {
+                return t->run(repo);
+            };
+            _repository->bytesToExtract += t->archiveSizeBytes();
+            _repository->addTask(cb);
+        } else {
+            SG_LOG(SG_TERRASYNC, SG_ALERT, "Unable to remove old file/directory " << removePath);
+        } // of pathAvailable
+    }
+
     void didFailToUpdateFile(const std::string& file,
-                             HTTPRepository::ResultCode status)
+                             HTTPRepository::ResultCode status,
+                             const std::string& details)
     {
         SGPath fpath(_relativePath);
         fpath.append(file);
-        _repository->failedToUpdateChild(fpath, status);
+        _repository->failedToUpdateChild(fpath, status, details);
     }
 
-    std::string hashForPath(const SGPath& p) const
+    std::string hashForSelf() const
     {
-        const auto ps = p.utf8Str();
-        auto it = hashes.find(ps);
-        if (it != hashes.end()) {
-            const auto& entry = it->second;
-            // ensure data on disk hasn't changed.
-            // we could also use the file type here if we were paranoid
-            if ((p.sizeInBytes() == entry.lengthBytes) && (p.modTime() == entry.modTime)) {
-                return entry.hashHex;
-            }
-
-            // entry in the cache, but it's stale so remove and fall through
-            hashes.erase(it);
-        }
-
-        std::string hash = computeHashForPath(p);
-        updatedFileContents(p, hash);
-        return hash;
+        const SGPath p = absolutePath() / ".dirindex";
+        return hashForPath(p, "SELF");
     }
 
     bool isHashCacheDirty() const
@@ -654,6 +655,29 @@ public:
 
 private:
 
+    std::string hashForPath(const SGPath& p, const std::string& key) const
+    {
+        auto it = hashes.find(key);
+        if (it != hashes.end()) {
+            const auto& entry = it->second;
+            // ensure data on disk hasn't changed.
+            // we could also use the file type here if we were paranoid
+            if ((p.sizeInBytes() == entry.lengthBytes) && (p.modTime() == entry.modTime)) {
+                return entry.hashHex;
+            } else {
+                SG_LOG(SG_TERRASYNC, SG_DEBUG, key << ": File is modified:" << p <<
+                    "\n\t" << entry.lengthBytes << " vs " << p.sizeInBytes() <<
+                    "\n\t" << entry.modTime << " vs " << p.modTime());
+            }
+
+            // entry in the cache, but it's stale so remove and fall through
+            hashes.erase(it);
+        }
+
+        std::string hash = computeHashForPath(p);
+        updatedFileContents(p, key, hash);
+        return hash;
+    }
     struct ChildWithName
     {
         ChildWithName(const std::string& n) : name(n) {}
@@ -680,8 +704,7 @@ private:
 
     bool parseDirIndex(ChildInfoList& children)
     {
-        SGPath p(absolutePath());
-        p.append(".dirindex");
+        const SGPath p = absolutePath() / ".dirindex";
         if (!p.exists()) {
             return false;
         }
@@ -775,7 +798,7 @@ private:
             ok = _repository->deleteDirectory(fpath, path);
         } else {
             // remove the hash cache entry
-            updatedFileContents(path, std::string());
+            updatedFileContents(path, path.file(), {});
             ok = path.remove();
         }
 
@@ -791,7 +814,51 @@ private:
       if (child.type == HTTPRepository::DirectoryType) {
           p.append(".dirindex");
       }
-      return hashForPath(p);
+      return hashForPath(p, child.name);
+    }
+
+    /**
+     * @brief helper function to deal with changed encoding of file names in the dirhash
+     * Previously we encoded the file absolute path, but this is annoying when files
+     * are relocated on disk. Now we store just the relative file name, and special value
+     * 'SELF' for the directory itself.
+     * 
+     * @param path candidate path from existing dirhash entry
+     * @return std::string updated hask entry key
+     */
+    std::string fixupEntryName(const std::string& path)
+    {
+        const auto lastSep = path.rfind('/');
+        if (lastSep == std::string::npos) {
+            // path doesn't contain any seperators, this means it's already fixed
+            return path;
+        }
+
+        // beyond this point, we are modifying, so mark the cache as dirty
+        hashCacheDirty = true;
+
+        const auto lastSegment =  path.substr(lastSep+1);
+        if (lastSegment != ".dirindex") {
+            // path is a regular file (or tarball), not a dir-index: use it directly
+            // since we know it will be unique
+            return lastSegment;
+        }
+
+        // 10 is length of the '/.dirindex' suffix which is not included in _relativePath
+        // but is included in (old style) hash cache entries
+        const auto pos = path.length() - (_relativePath.length() + 10);
+
+        // check if entry is for us, by comparing the with our relative path in the repo.
+        if (path.compare(pos, _relativePath.length(), _relativePath) == 0) {
+            return "SELF";
+        }
+
+        // we're dealing with a path of a directory, we need to establish the parent is us
+        // or a child directory
+        const auto penultimateSep = path.rfind('/', lastSep - 1);
+        const auto dirSegment = path.substr(penultimateSep + 1, lastSep - (penultimateSep + 1));
+
+        return dirSegment;
     }
 
     void parseHashCache()
@@ -816,7 +883,8 @@ private:
                 SG_LOG(SG_TERRASYNC, SG_WARN, "invalid entry in '" << cachePath << "': '" << line << "' (ignoring line)");
                 continue;
             }
-            const std::string nameData = simgear::strutils::strip(tokens[0]);
+            
+            const auto nameData = fixupEntryName(simgear::strutils::strip(tokens[0]));
             const std::string timeData = simgear::strutils::strip(tokens[1]);
             const std::string sizeData = simgear::strutils::strip(tokens[2]);
             const std::string hashData = simgear::strutils::strip(tokens[3]);
@@ -835,11 +903,10 @@ private:
         }
     }
 
-    void updatedFileContents(const SGPath& p, const std::string& newHash) const
+    void updatedFileContents(const SGPath& p, const std::string& key, const std::string& newHash) const
     {
         // remove the existing entry
-        const auto ps = p.utf8Str();
-        auto it = hashes.find(ps);
+        auto it = hashes.find(key);
         if (it != hashes.end()) {
             hashes.erase(it);
             hashCacheDirty = true;
@@ -855,11 +922,11 @@ private:
         p2.set_cached(true);
 
         HashCacheEntry entry;
-        entry.filePath = ps;
+        entry.filePath = key;
         entry.hashHex = newHash;
         entry.modTime = p2.modTime();
         entry.lengthBytes = p2.sizeInBytes();
-        hashes.insert(std::make_pair(ps, entry));
+        hashes.insert(std::make_pair(key, entry));
 
         hashCacheDirty = true;
     }
@@ -948,10 +1015,9 @@ void HTTPRepository::process()
 
 void HTTPRepoPrivate::checkForComplete()
 {
-  if (pendingTasks.empty() && activeRequests.empty() &&
-      queuedRequests.empty()) {
-    isUpdating = false;
-  }
+    if (pendingTasks.empty() && activeRequests.empty() && queuedRequests.empty()) {
+        isUpdating = false;
+    }
 }
 
 size_t HTTPRepository::bytesToDownload() const
@@ -966,8 +1032,7 @@ size_t HTTPRepository::bytesToDownload() const
     for (r = _d->activeRequests.begin(); r != _d->activeRequests.end(); ++r) {
         if ((*r)->contentSize() > 0) {
             // Content size for root dirindex of a repository is zero,
-            // and returing a negative value breaks everyting, so just ignore
-            // it
+            // and returning a negative value breaks everything, so just ignore it
             result += (*r)->contentSize() - (*r)->responseBytesReceived();
         }
     }
@@ -1006,6 +1071,11 @@ HTTPRepository::FailureVec HTTPRepository::failures() const {
   return _d->failures;
 }
 
+SGPath HTTPRepository::lastCheckedPath() const
+{
+    return _d->lastUpdatedDir;
+}
+
 void HTTPRepository::setFilter(SyncPredicate sp) { _d->syncPredicate = sp; }
 
 HTTPRepository::ResultCode
@@ -1020,7 +1090,7 @@ HTTPRepository::failure() const
 
     void HTTPRepoGetRequest::cancel()
     {
-        _directory->repository()->http->cancelRequest(this, "Repository cancelled");
+        _directory->repository()->http->cancelRequest(this, "Repository cancelled"s);
         _directory = 0;
     }
 
@@ -1043,7 +1113,7 @@ HTTPRepository::failure() const
                 if (!ok) {
                     ioFailureOccurred = true;
                     _directory->repository()->http->cancelRequest(
-                        this, "Unable to create output file:" + pathInRepo.utf8Str());
+                        this, "Unable to create output file:"s + pathInRepo.utf8Str());
                 }
             }
 
@@ -1089,19 +1159,13 @@ HTTPRepository::failure() const
                     strutils::encodeHex(sha1_result(&hashContext), HASH_LENGTH);
                 _directory->didUpdateFile(fileName, hash, contentSize());
             } else if (responseCode() == 404) {
-                SG_LOG(SG_TERRASYNC, SG_WARN,
-                       "terrasync file not found on server: "
-                           << fileName << " for " << _directory->absolutePath());
                 _directory->didFailToUpdateFile(
-                    fileName, HTTPRepository::REPO_ERROR_FILE_NOT_FOUND);
+                    fileName, HTTPRepository::REPO_ERROR_FILE_NOT_FOUND,
+                    "File not found on the server"s);
             } else {
-                SG_LOG(SG_TERRASYNC, SG_WARN,
-                       "terrasync file download error on server: "
-                           << fileName << " for " << _directory->absolutePath()
-                           << "\n\tserver responded: " << responseCode() << "/"
-                           << responseReason());
                 _directory->didFailToUpdateFile(fileName,
-                                                HTTPRepository::REPO_ERROR_HTTP);
+                                                HTTPRepository::REPO_ERROR_HTTP,
+                                                "HTTP request failed with code:"s + std::to_string(responseCode()) + "/"s + responseReason());
                 // should we every retry here?
             }
 
@@ -1132,12 +1196,12 @@ HTTPRepository::failure() const
         }
 
         if (_directory) {
-          _directory->didFailToUpdateFile(fileName, code);
+            _directory->didFailToUpdateFile(fileName, code, "HTTP client failed request for:"s + url());
 
-          const auto doRetry = code == HTTPRepository::REPO_ERROR_SOCKET
-                                   ? HTTPRepoPrivate::RequestFinish::Retry
-                                   : HTTPRepoPrivate::RequestFinish::Done;
-          _directory->repository()->finishedRequest(this, doRetry);
+            const auto doRetry = code == HTTPRepository::REPO_ERROR_SOCKET
+                                     ? HTTPRepoPrivate::RequestFinish::Retry
+                                     : HTTPRepoPrivate::RequestFinish::Done;
+            _directory->repository()->finishedRequest(this, doRetry);
         }
       }
 
@@ -1202,22 +1266,15 @@ HTTPRepository::failure() const
             std::string hash =
                 strutils::encodeHex(sha1_result(&hashContext), HASH_LENGTH);
             if (!_targetHash.empty() && (hash != _targetHash)) {
-              SG_LOG(SG_TERRASYNC, SG_ALERT,
-                     "Checksum error getting dirIndex for:"
-                         << _directory->relativePath() << "; expected "
-                         << _targetHash << " but received " << hash
-                         << " url()=" << url()
-                         );
+                _directory->failedToUpdate(HTTPRepository::REPO_ERROR_CHECKSUM, "checksum error, expected:"s + _targetHash + ", but got:"s + hash);
 
-              _directory->failedToUpdate(HTTPRepository::REPO_ERROR_CHECKSUM);
-
-              // don't retry checksums failures
-              _directory->repository()->finishedRequest(
-                  this, HTTPRepoPrivate::RequestFinish::Done);
-              return;
+                // don't retry checksums failures
+                _directory->repository()->finishedRequest(
+                    this, HTTPRepoPrivate::RequestFinish::Done);
+                return;
             }
 
-            std::string curHash = _directory->hashForPath(path());
+            std::string curHash = _directory->hashForSelf();
             if (hash != curHash) {
               simgear::Dir d(_directory->absolutePath());
               if (!d.exists()) {
@@ -1241,7 +1298,6 @@ HTTPRepository::failure() const
               _directory->dirIndexUpdated(hash);
 
               SG_LOG(SG_TERRASYNC, SG_DEBUG, "from url()=" << url() << " have updated _directory: " << _directory);
-              //SG_LOG(SG_TERRASYNC, SG_INFO, "updated dir index " << _directory->absolutePath());
             }
 
             _directory->repository()->totalDownloaded += contentSize();
@@ -1256,14 +1312,14 @@ HTTPRepository::failure() const
                      "after update of:" << _directory->absolutePath()
                                         << " child update took:"
                                         << st.elapsedMSec());
-            } catch (sg_exception &) {
-              _directory->failedToUpdate(HTTPRepository::REPO_ERROR_IO);
+            } catch (sg_exception& e) {
+                _directory->failedToUpdate(HTTPRepository::REPO_ERROR_IO, "Exception updating children:" + e.getFormattedMessage());
             }
           } else if (responseCode() == 404) {
-            _directory->failedToUpdate(
-                HTTPRepository::REPO_ERROR_FILE_NOT_FOUND);
+              _directory->failedToUpdate(
+                  HTTPRepository::REPO_ERROR_FILE_NOT_FOUND, "Server returned 404/NOT FOUND");
           } else {
-            _directory->failedToUpdate(HTTPRepository::REPO_ERROR_HTTP);
+              _directory->failedToUpdate(HTTPRepository::REPO_ERROR_HTTP, "HTTP failed with:" + std::to_string(responseCode()) + "/"s + responseReason());
           }
 
           _directory->repository()->finishedRequest(
@@ -1278,14 +1334,12 @@ HTTPRepository::failure() const
             code = HTTPRepository::REPO_ERROR_CANCELLED;
           }
 
-          SG_LOG(SG_TERRASYNC, SG_WARN,
-                 "Socket failure getting directory: " << url());
           if (_directory) {
-            _directory->failedToUpdate(code);
-            const auto doRetry = code == HTTPRepository::REPO_ERROR_SOCKET
-                                     ? HTTPRepoPrivate::RequestFinish::Retry
-                                     : HTTPRepoPrivate::RequestFinish::Done;
-            _directory->repository()->finishedRequest(this, doRetry);
+              _directory->failedToUpdate(code, "HTTP layer failed request for:"s + url());
+              const auto doRetry = code == HTTPRepository::REPO_ERROR_SOCKET
+                                       ? HTTPRepoPrivate::RequestFinish::Retry
+                                       : HTTPRepoPrivate::RequestFinish::Done;
+              _directory->repository()->finishedRequest(this, doRetry);
           }
         }
 
@@ -1319,7 +1373,7 @@ HTTPRepository::failure() const
         }
 
         flushHashCaches();
-        directories.clear(); // wil delete them all
+        directories.clear(); // will delete them all
     }
 
     HTTP::Request_ptr HTTPRepoPrivate::updateFile(HTTPDirectory* dir, const std::string& name, size_t sz)
@@ -1414,34 +1468,29 @@ HTTPRepository::failure() const
       checkForComplete();
     }
 
-    void HTTPRepoPrivate::failedToGetRootIndex(HTTPRepository::ResultCode st)
+    void HTTPRepoPrivate::failedToGetRootIndex(HTTPRepository::ResultCode st, const std::string& details)
     {
         if (st == HTTPRepository::REPO_ERROR_FILE_NOT_FOUND) {
             status = HTTPRepository::REPO_ERROR_NOT_FOUND;
         } else {
             simgear::reportFailure(simgear::LoadFailure::NetworkError, simgear::ErrorCode::TerraSync,
-                                   "failed to get TerraSync repository root:" + innerResultCodeAsString(st),
+                                   "failed to get TerraSync repository root:" + innerResultCodeAsString(st) + "\n\t" + details,
                                    sg_location{baseUrl});
-            SG_LOG(SG_TERRASYNC, SG_WARN, "Failed to get root of repo:" << baseUrl << " " << st);
             status = st;
         }
     }
 
     void HTTPRepoPrivate::failedToUpdateChild(const SGPath& relativePath,
-                                              HTTPRepository::ResultCode fileStatus)
+                                              HTTPRepository::ResultCode fileStatus,
+                                              const std::string& details)
     {
       if (fileStatus == HTTPRepository::REPO_ERROR_CANCELLED) {
         // if we were cancelled, don't report or log
         return;
       } else {
-        SG_LOG(SG_TERRASYNC, SG_WARN,
-               "failed to update entry:" << relativePath << " status/code: "
-                                         << innerResultCodeAsString(fileStatus)
-                                         << "/" << fileStatus);
-
-        simgear::reportFailure(simgear::LoadFailure::NetworkError, simgear::ErrorCode::TerraSync,
-                               "failed to update entry:" + innerResultCodeAsString(fileStatus),
-                               sg_location{relativePath});
+          simgear::reportFailure(simgear::LoadFailure::NetworkError, simgear::ErrorCode::TerraSync,
+                                 "failed to update entry:" + innerResultCodeAsString(fileStatus) + "\n\t" + details,
+                                 sg_location{relativePath});
       }
 
       HTTPRepository::Failure f;
