@@ -36,6 +36,7 @@
 #include <cstring>
 #include <cassert>
 #include <cstdio> // for snprintf
+#include <mutex>
 #include <errno.h>
 
 #if defined(WINSOCK)
@@ -213,7 +214,7 @@ private:
       return ok;
     }
 
-    SGMutex _lock;
+    std::mutex _lock;
     SGWaitCondition _wait;
 
     typedef std::map<string, simgear::IPAddress*> AddressCache;
@@ -238,7 +239,8 @@ IPAddress::IPAddress( const IPAddress& other ) :
 {
   if (other.addr) {
     addr = (struct sockaddr_in*) malloc(sizeof(struct sockaddr_in));
-    memcpy(addr, other.addr, sizeof(struct sockaddr_in));
+    if (addr)
+      memcpy(addr, other.addr, sizeof(struct sockaddr_in));
   }
 }
 
@@ -251,7 +253,8 @@ const IPAddress& IPAddress::operator=(const IPAddress& other)
 
   if (other.addr) {
     addr = (struct sockaddr_in*) malloc(sizeof(struct sockaddr_in));
-    memcpy(addr, other.addr, sizeof(struct sockaddr_in));
+    if (addr)
+      memcpy(addr, other.addr, sizeof(struct sockaddr_in));
   }
 
   return *this;
@@ -275,10 +278,14 @@ void IPAddress::set ( const char* host, int port )
     return;
   }
 
+//for 2024.1 remove use of <broadcast> and replace with a warning and hint.
   if (strcmp(host, "<broadcast>") == 0) {
+    SG_LOG(SG_IO, SG_ALERT, "Use of <broadcast> to represent a socket broadcast address has been depricated.");
+    SG_LOG(SG_IO, SG_ALERT, "   Please try something like --generic=socket,broadcast,10,255.255.255.255,...");
+    SG_LOG(SG_IO, SG_ALERT, "   A directed broadcast address for a specific network may be more appropriate.");
     addr->sin_addr.s_addr = INADDR_BROADCAST;
     return;
-  }
+  } 
 
 // check the cache
   IPAddress* cached = Resolver::instance()->lookupSync(host);
@@ -319,10 +326,10 @@ const char* IPAddress::getHost () const
     
   static char buf [32];
 	long x = ntohl(addr->sin_addr.s_addr);
-	sprintf(buf, "%d.%d.%d.%d",
-		(int) (x>>24) & 0xff, (int) (x>>16) & 0xff,
-		(int) (x>> 8) & 0xff, (int) (x>> 0) & 0xff );
-  return buf;
+    snprintf(buf, 32, "%d.%d.%d.%d",
+             (int)(x >> 24) & 0xff, (int)(x >> 16) & 0xff,
+             (int)(x >> 8) & 0xff, (int)(x >> 0) & 0xff);
+    return buf;
 }
 
 unsigned int IPAddress::getIP () const
@@ -382,16 +389,6 @@ const char* IPAddress::getLocalHost ()
   return "127.0.0.1" ;
 }
 
-
-bool IPAddress::getBroadcast () const
-{
-    if (!addr) {
-        return false;
-    }
-    
-    return (addr->sin_addr.s_addr == INADDR_BROADCAST);
-}
-
 unsigned int IPAddress::getAddrLen() const
 {
     return sizeof(struct sockaddr_in);
@@ -599,9 +596,6 @@ int Socket::connect ( const char* host, int port )
 int Socket::connect ( IPAddress* addr )
 {
   assert ( handle != -1 ) ;
-  if ( addr->getBroadcast() ) {
-      setBroadcast( true );
-  }
   return ::connect(handle, addr->getAddr(), addr->getAddrLen() );
 }
 
